@@ -28,11 +28,15 @@ class Cia_table(object):
                 Relative or absolute name of the file to be loaded. 
             filename_filters: sequence of string
                 As many strings as necessary to uniquely define
-                a file in the global search path defined in
-                :class:`~exo_k.settings.Settings`.
+                a file in the global search path defined with
+                :func:`exo_k.settings.Settings.set_cia_search_path`.
                 This path will be searched for a file
                 with all the filename_filters in the name.
                 The filename_filters can contain '*'.
+            molecule_pair: list of size 2, optional
+                The molecule pair we want to consider, 
+                specified as an array with two strings (like ['H2','H2'] or ['N2','H2O']).
+                The order of the molecules in the pair is irrelevant. 
 
         Other Parameters
         ----------------
@@ -47,9 +51,9 @@ class Cia_table(object):
                     a value 10 orders of magnitude smaller than the smallest positive value
             search_path: str, optional
                 If search_path is provided,
-                it locally overrides the global _search_path
-                in :class:`~exo_k.settings.Settings`
-                and only files in search_path are returned.
+                it locally overrides the global search path
+                defined with :func:`exo_k.settings.Settings.set_cia_search_path`
+                and only files in `search_path` are returned.
         """
         self._init_empty()
         self._settings=Settings()
@@ -162,7 +166,10 @@ class Cia_table(object):
         self.abs_coeff=f['abs_coeff'][...]
         self.abs_coeff_unit=f['abs_coeff'].attrs['units']
         self.tgrid=f['t'][...]
-        self.mol1,self.mol2=f.attrs['cia_pair'].split('-')
+        if 'cia_pair' in f:
+            self.mol1,self.mol2=f['cia_pair'][()].split('-')
+        elif 'cia_pair' in f.attrs:
+            self.mol1,self.mol2=f.attrs['cia_pair'].split('-')
         f.close()  
         self.wnedges=np.concatenate(([self.wns[0]],0.5*(self.wns[1:]+self.wns[:-1]),[self.wns[-1]]))
         self.Nt=self.tgrid.size
@@ -183,8 +190,7 @@ class Cia_table(object):
         f.create_dataset("t", data=self.tgrid,compression="gzip")
         f.create_dataset("abs_coeff", data=self.abs_coeff,compression="gzip")
         f["abs_coeff"].attrs["units"] = self.abs_coeff_unit
-        f.attrs["cia_pair"] = self.mol1+'-'+self.mol2
-        #f.create_dataset("cia_pair", data=self.mol1+'-'+self.mol2)
+        f.create_dataset("cia_pair", data=self.mol1+'-'+self.mol2)
         f.close()    
 
     def sample(self, wngrid, remove_zeros=False, use_grid_filter=False, **kwargs):
@@ -266,16 +272,14 @@ class Cia_table(object):
             for ii in range(tind.size):
                 kc_t1=np.log(self.abs_coeff[tind[ii]][wngrid_filter].ravel())
                 kc_t0=np.log(self.abs_coeff[tind[ii]-1][wngrid_filter].ravel())
-                tmp=linear_interpolation(kc_t0, kc_t1, tweight[ii])
-                res[ii]=np.reshape(tmp,(Nw,-1)).squeeze()
+                res[ii]=linear_interpolation(kc_t0, kc_t1, tweight[ii])
             return np.exp(res)
         else:
             for ii in range(tind.size):
                 #kc_t1=self.abs_coeff[tind[ii]]
                 kc_t1=self.abs_coeff[tind[ii]][wngrid_filter].ravel()
                 kc_t0=self.abs_coeff[tind[ii]-1][wngrid_filter].ravel()
-                tmp=linear_interpolation(kc_t0, kc_t1, tweight[ii])
-                res[ii]=np.reshape(tmp,(Nw,-1)).squeeze()
+                res[ii]=linear_interpolation(kc_t0, kc_t1, tweight[ii])
             return res
 
     def equivalent_xsec(self, logP, T, x_mol2, wngrid_limit=None):
