@@ -153,17 +153,25 @@ class Xtable(Data_table):
         if (filename is None or not filename.lower().endswith(('.hdf5', '.h5'))):
             raise RuntimeError("You should provide an input hdf5 file")
         f = h5py.File(filename, 'r')
-        if 'mol_name' in f.attrs:
+        if 'mol_name' in f:
+            self.mol=f['mol_name'][()]
+        elif 'mol_name' in f.attrs:
             self.mol=f.attrs['mol_name']
         else:
             self.mol=os.path.basename(filename).split(self._settings._delimiter)[0]
+        if isinstance(self.mol, np.ndarray): self.mol=self.mol[0]
         if mol is not None:
             self.mol=mol
-        self.wns=f['bin_edges'][...]
+        if 'bin_edges' in f:
+            self.wns=f['bin_edges'][...]
+            if 'units' in f['bin_edges'].attrs:
+                self.wn_unit=f['bin_edges'].attrs['units']
+        else:
+            self.wns=f['bin_centers'][...]
+            if 'units' in f['bin_centers'].attrs:
+                self.wn_unit=f['bin_centers'].attrs['units']
         self.wnedges=np.concatenate(  \
             ([self.wns[0]],(self.wns[:-1]+self.wns[1:])*0.5,[self.wns[-1]]))
-        if 'units' in f['bin_edges'].attrs:
-            self.wn_unit=f['bin_edges'].attrs['units']
         self.kdata=f['xsecarr'][...]
         self.kdata_unit=f['xsecarr'].attrs['units']
         self.tgrid=f['t'][...]
@@ -187,7 +195,7 @@ class Xtable(Data_table):
             fullfilename=filename+'.hdf5'
         compression="gzip"
         f = h5py.File(fullfilename, 'w')
-        f.attrs["mol_name"] = self.mol
+        f.create_dataset("mol_name", data=self.mol)
         f.create_dataset("p", data=self.pgrid,compression=compression)
         f["p"].attrs["units"] = self.p_unit
         f.create_dataset("t", data=self.tgrid,compression=compression)
